import nfdrs4py
import pandas as pd
import numpy as np
import requests
import io
import time

time_start = time.time()
import nfdrs4py
config = nfdrs4py.read_config('data/NFDRSInitSample.txt')
interface = nfdrs4py.NFDRS4py.init_from_config(config)
interface.set_fuel_moisture(0,0,0,0,1,1)

wx = pd.read_csv('data/241513_2001_2017.fw21')
results = interface.process_df(wx)
results.to_csv('data/results_py.csv')
print(results)
print('Finished in: ',time.time() - time_start)


import os
from typing import Union

import numpy as np


class NFDRS4py():
    """Simplified interface object for NFDRS4"""

    def __init__(self,
                 Lat:float=40.,
                 FuelModel:str='W',
                 SlopeClass:int=1,
                 AvgAnnPrecip:float=30.,
                 MCInit1hr:float=0.2,
                 MCInit10hr: float = 0.2,
                 MCInit100hr: float = 0.2,
                 MCInit1000hr: float = 0.2,
                 MCInitLWoody: float = 0.2,
                 MCInitLHerb: float = 0.2,
                 LT:bool=True,
                 Cure:bool=True,
                 isAnnual:bool=True,
                 kbdiThreshold:float=100,
                 RegObsHour:int=13,
                 isReinit:bool=False):
        """Initialization function for NFDRS4 object with simplified interface

        Arguments:

        Lat: The latitude of the simulation point (decimal degrees).
        FuelModel: Fuel model character code (V: Grass, W: Grass-Shrub, X: Brush, Y: Timber, Z: Slash).
        SlopeClass: Slope class (1 = <25%, 2 = 26-40%, 3 = 41 - 55%, 4 = 56 - 75%, 5 = 76%+).
        AvgAnnPrecip: Mean annual precipitation (inches).
        MCInit1hr: initial moisture content for 1hr dead fuel,
        MCInit10hr: initial moisture content for 10hr dead fuel
        MCInit100hr: initial moisture content for 100hr dead fuel
        MCInit1000hr: initial moisture content for 1000hr dead fuel
        MCInitLWoody: initial moisture content for live woody fuel
        MCInitLHerb: initial moisture content for live herbaceous fuel
        LT: Use drought fuel load transfer (boolean).
        Cure: Use herbaceous curing (boolean).
        IsAnnual: Treat herbs as annual (boolean).
        kbdiThreshold: Starting KBDI value to begin drought fuel load additions (default 100).
        RegObsHour: Regular observation hour; triggers daily GSI-LFMC calculation (default 13).
        isReinit: If true, indicates re-initialization mid-calculation (not common)."""

        from .nfdrs4_bindings import NFDRS4

        self.nfdrs4 = NFDRS4()
        self.nfdrs4.Init(Lat=Lat,FuelModel=FuelModel,SlopeClass=SlopeClass,AvgAnnPrecip=AvgAnnPrecip,LT=LT, Cure=Cure,
                         isAnnual=isAnnual,kbdiThreshold=kbdiThreshold,RegObsHour=RegObsHour,isReinit=isReinit)

        #self.set_one_hr_params()
        #self.set_ten_hr_params()
        #self.set_hundred_hr_params()
        #self.set_thousand_hr_params()
        #self.set_gsi_params()
        #self.set_herb_gsi_params()
        #self.set_woody_gsi_params()
        #self.set_start_kbdi()
        #self.set_sc_max()
        #self.set_mxd()

        self.set_fuel_moisture(MCInit1hr,MCInit10hr,MCInit100hr,MCInit1000hr,MCInitLWoody,MCInitLHerb)

    def set_from_config(self,config:Union[dict[dict],str])->None:
        """Set NFDRS4py variables from configuration file or dictionary.

        First level keys must be 'general', 'liveFuelMoisture.defaults', 'gsi_opts', 'herb_opts', 'woody_opts',
        'deadFuelMoisture.defaults', '1hr_opts', '10hr_opts', '100hr_opts', '1000hr_opts', and/or 'customFuelModel'
        Second level keys must match variable names in associated nfdrs4py setter
        """
        if type(config) is not dict:
            config = read_config(config)

        self.nfdrs4.Init(config['general']['latitude'],config['general']['fuelmodel'],config['general']['slopeclass'],
                         config['general']['avgannualprecip'],bool(config['general']['useloadtransfer']),
                         bool(config['general']['usecure']),bool(config['general']['isannuals']),
                         config['general']['kbdithreshold'],config['general']['startkbdi'],False)
        if 'customFuelModel' in config.keys():
            self.set_custom_fuel_model(**config['customFuelModel'])
        if '1hr_opts' in config.keys():
            self.set_one_hr_params(**config['1hr_opts'])
        if '10hr_opts' in config.keys():
            self.set_ten_hr_params(**config['10hr_opts'])
        if '100hr_opts' in config.keys():
            self.set_hundred_hr_params(**config['100hr_opts'])
        if '1000hr_opts' in config.keys():
            self.set_thousand_hr_params(**config['1000hr_opts'])
        if 'gsi_opts' in config.keys():
            gsi_opts_reduced = ['gsimax', 'gsiherbgreenup', 'gsitminmin', 'gsitminmax',
                                'gsivpdmin', 'gsivpdmax', 'gsidaylenmin', 'gsidaylenmax',
                                'gsiaveragingdays', 'gsiusevpdavg', 'gsinumprecipdays',
                                'gsirtprecipmin', 'gsirtprecipmax', 'gsiusertprecip']
            gsi_opts_reduced = {k: v for k, v in config['gsi_opts'].items() if k in gsi_opts_reduced}
            self.set_gsi_params(**gsi_opts_reduced)
        if 'herb_opts' in config.keys():
            self.set_herb_gsi_params(**config['herb_opts'])
        if 'woody_opts' in config.keys():
            self.set_woody_gsi_params(**config['woody_opts'])
        if 'kbdi' in config['general'].keys():
            self.set_start_kbdi(config['general'])
        if 'maxsc' in config['general'].keys() and config['general']['maxsc'] > 0:
            self.set_sc_max(config['general']['maxsc'])
        if 'mxd' in config['general'].keys() and config['general']['mxd'] > 0:
            self.set_mxd(config['general']['mxd'])

    def set_custom_fuel_model(self, fuelmodel:str = 'C',
                              description:str = 'Custom',
                              sg1:float = 2000,
                              sg10:float = 109,
                              sg100:float = 30,
                              sg1000:float = 8,
                              sgwood:float = 1500,
                              sgherb:float = 2000,
                              hd:float = 8000,
                              l1:float = 2.5,
                              l10:float = 2,
                              l100:float = 5,
                              l1000:float = 12,
                              lwood:float = .5,
                              lherb:float = .5,
                              depth:float = 1,
                              mxd:float = 25,
                              scm:float = 30,
                              ldrought:float = 0,
                              wndfc:float = .4)->None:
        """Set up and use a custom fuel model for fire danger indices"""

        from .nfdrs4_bindings import CFuelModelParams
        params = CFuelModelParams()
        params.setFuelModel(fuelmodel)
        params.setDescription(description)
        params.setSG1(sg1)
        params.setSG10(sg10)
        params.setSG100(sg100)
        params.setSG1000(sg1000)
        params.setSGWood(sgwood)
        params.setSGHerb(sgherb)
        params.setHD(hd)
        params.setL1(l1)
        params.setL10(l10)
        params.setL100(l100)
        params.setL1000(l1000)
        params.setLWood(lwood)
        params.setLHerb(lherb)
        params.setDepth(depth)
        params.setMXD(mxd)
        params.setSCM(scm)
        params.setLDrought(ldrought)
        params.setWNDFC(wndfc)

        self.nfdrs4.AddCustomFuel(params)
        self.nfdrs4.iSetFuelModel(params.getFuelModel())

    def set_one_hr_params(self, radius:float = .2,
                          adsorptionrate:float = .462252733,
                          maxlocalmoisture:float = .35,
                          stickdensity:float = .4,
                          desorptionrate:float = .06)->None:

        self.nfdrs4.SetOneHourParams(radius,adsorptionrate,maxlocalmoisture,stickdensity,desorptionrate)

    def set_ten_hr_params(self, radius:float = .64,
                          adsorptionrate:float = .079548303,
                          maxlocalmoisture:float = .35,
                          stickdensity:float = .4,
                          desorptionrate:float = .06)->None:

        self.nfdrs4.SetTenHourParams(radius, adsorptionrate, maxlocalmoisture, stickdensity, desorptionrate)

    def set_hundred_hr_params(self, radius:float = 2.0,
                          adsorptionrate:float = .06,
                          maxlocalmoisture:float = .35,
                          stickdensity:float = .4,
                          desorptionrate:float = .06)->None:

        self.nfdrs4.SetHundredHourParams(radius, adsorptionrate, maxlocalmoisture, stickdensity, desorptionrate)

    def set_thousand_hr_params(self, radius:float = 3.81,
                          adsorptionrate:float = .06,
                          maxlocalmoisture:float = .35,
                          stickdensity:float = .4,
                          desorptionrate:float = .06)->None:

        self.nfdrs4.SetHundredHourParams(radius, adsorptionrate, maxlocalmoisture, stickdensity, desorptionrate)

    def set_gsi_params(
        self, gsimax: float = 1, gsiherbgreenup: float = .5, gsitminmin: float = -2.0, gsitminmax: float = 5.0,
        gsivpdmin: float = 900, gsivpdmax: float = 4100, gsidaylenmin: float = 36000, gsidaylenmax: float = 39600,
        gsiaveragingdays: int = 21, gsiusevpdavg: bool = False, gsinumprecipdays: int = 30,
        gsirtprecipmin: float = 0.5, gsirtprecipmax: float = 1.5, gsiusertprecip: bool = False
    ) -> None:
        self.nfdrs4.SetGSIParams(
            gsimax, gsiherbgreenup, gsitminmin, gsitminmax, gsivpdmin, gsivpdmax,
            gsidaylenmin, gsidaylenmax, gsiaveragingdays, bool(gsiusevpdavg), gsinumprecipdays,
            gsirtprecipmin, gsirtprecipmax, bool(gsiusertprecip)
        )

    def set_herb_gsi_params(
        self, gsimax: float = 1, gsiherbgreenup: float = .5, gsitminmin: float = -2.0, gsitminmax: float = 5.0,
        gsivpdmin: float = 900, gsivpdmax: float = 4100, gsidaylenmin: float = 36000, gsidaylenmax: float = 39600,
        gsiaveragingdays: int = 21, gsiusevpdavg: bool = False, gsinumprecipdays: int = 30,
        gsirtprecipmin: float = 0.5, gsirtprecipmax: float = 1.5, gsiusertprecip: bool = False,
        fuelmoisturemin: float = 30.0, fuelmoisturemax: float = 250.0
    ) -> None:
        self.nfdrs4.SetHerbGSIparams(
            gsimax, gsiherbgreenup, gsitminmin, gsitminmax, gsivpdmin, gsivpdmax,
            gsidaylenmin, gsidaylenmax, gsiaveragingdays, bool(gsiusevpdavg), gsinumprecipdays,
            gsirtprecipmin, gsirtprecipmax, bool(gsiusertprecip), fuelmoisturemin, fuelmoisturemax
        )

    def set_woody_gsi_params(
        self, gsimax: float = 1, gsiherbgreenup: float = .5, gsitminmin: float = -2.0, gsitminmax: float = 5.0,
        gsivpdmin: float = 900, gsivpdmax: float = 4100, gsidaylenmin: float = 36000, gsidaylenmax: float = 39600,
        gsiaveragingdays: int = 21, gsiusevpdavg: bool = False, gsinumprecipdays: int = 30,
        gsirtprecipmin: float = 0.5, gsirtprecipmax: float = 1.5, gsiusertprecip: bool = False,
        fuelmoisturemin: float = 60.0, fuelmoisturemax: float = 200.0
    ) -> None:
        self.nfdrs4.SetWoodyGSIparams(
            gsimax, gsiherbgreenup, gsitminmin, gsitminmax, gsivpdmin, gsivpdmax,
            gsidaylenmin, gsidaylenmax, gsiaveragingdays, bool(gsiusevpdavg), gsinumprecipdays,
            gsirtprecipmin, gsirtprecipmax, bool(gsiusertprecip), fuelmoisturemin, fuelmoisturemax
        )

    def set_start_kbdi(self,skbdi=100)->None:
        """Starting drought index"""
        self.nfdrs4.SetStartKBDI(skbdi)

    def set_sc_max(self,maxsc=0)->None:
        """Max spread component? Any positive value other than zero overrides fuel model default."""
        self.nfdrs4.SetSCMax(maxsc)

    def set_mxd(self,mxd=0)->None:
        """Moisture of extinction. Any positive value other than zero overrides fuel model default."""
        self.nfdrs4.SetMXD(mxd)

    def set_fuel_moisture(self,dmc_1hr=.2,dmc_10hr=.2,dmc_100hr=.2,dmc_1000hr=.2,lmc_woody=.6,lmc_herb=.3,fuel_temp_C=-999)->None:
        """Set fuel moisture directly, typically to set initial conditions"""
        self.nfdrs4.OneHourFM.setMoisture(dmc_1hr)
        self.nfdrs4.TenHourFM.setMoisture(dmc_10hr)
        self.nfdrs4.HundredHourFM.setMoisture(dmc_100hr)
        self.nfdrs4.ThousandHourFM.setMoisture(dmc_1000hr)
        self.nfdrs4.MC1 = dmc_1hr
        self.nfdrs4.MC10 = dmc_10hr
        self.nfdrs4.MC100 = dmc_100hr
        self.nfdrs4.MC1000 = dmc_1000hr
        self.nfdrs4.iSetFuelMoistures(dmc_1hr, dmc_10hr, dmc_100hr, dmc_1000hr, lmc_woody, lmc_herb, fuel_temp_C)

    def update_weather(self,
               Year: int,
               Month: int,
               Day: int,
               Hour: int,
               Temp: float,
               RH: float,
               PPTAmt: float,
               SolarRad: float,
               WS: float,
               SnowDay: bool)->None:
        """Initialize a new timestep by providing new weather data. Units are US customary, time is local.

        Args:
            Year: year of observation (local time, not utc/zulu)
            Month: month of observation (local time, not utc/zulu)
            Day: day of observation (local time, not utc/zulu)
            Hour: hour of observation (local time, not utc/zulu)
            Temp: air temperature, degrees F
            RH: relative humidity, percent, expressed as value between 0 and 100
            PPTAmt: precipitation in this hour, inches
            SolarRad: solar radiation, watts per sq meter
            WS: wind speed, miles per hour
            SnowDay: boolean flag for snow day (check FW21 documentation)
        """

        self.nfdrs4.Update(int(Year),int(Month),int(Day),int(Hour),float(Temp),float(RH),float(PPTAmt),
                           float(SolarRad),float(WS),bool(SnowDay))

    def update_weather_metric(self,
               Year: int,
               Month: int,
               Day: int,
               Hour: int,
               Temp: float,
               RH: float,
               PPTAmt: float,
               SolarRad: float,
               WS_km_hr: float = None,
               WS_m_s: float = None,
               SnowDay: bool=False):
        """Initialize a new timestep by providing new weather data. Units are metric, time is local.

        Args:
            Year: year of observation (local time, not utc/zulu)
            Month: month of observation (local time, not utc/zulu)
            Day: day of observation (local time, not utc/zulu)
            Hour: hour of observation (local time, not utc/zulu)
            Temp: air temperature, degrees C
            RH: relative humidity, percent, expressed as value between 0 and 100
            PPTAmt: precipitation in this hour, cm
            SolarRad: solar radiation, watts per sq meter
            WS_km_hr: wind speed, km per hour. Must be provided if WS_m_s is None.
            WS_m_s: wind speed, meters per second. Must be provided if WS_km_hr is None.
            SnowDay: boolean flag for snow day (check FW21 documentation)
        """
        Temp = Temp * 1.8 + 32
        PPTAmt /= 2.54
        if WS_km_hr is not None:
            WS = WS_km_hr / 1.609344
        elif WS_m_s is not None:
            WS = WS_m_s * 2.2369362921
        else:
            raise ValueError("Either WS_km_hr or WS_m_s must be provided.")

        self.nfdrs4.Update(int(Year),int(Month),int(Day),int(Hour),float(Temp),float(RH),float(PPTAmt),
                           float(SolarRad),float(WS),bool(SnowDay))

    def get_current_fuel_moisture(self)->dict[float]:
        d = {'dmc_1_hr':self.nfdrs4.MC1,
             'dmc_10_hr':self.nfdrs4.MC10,
             'dmc_100_hr':self.nfdrs4.MC100,
             'dmc_1000_hr':self.nfdrs4.MC1000,
             'lmc_herb':self.nfdrs4.MCHERB,
             'lmc_woody':self.nfdrs4.MCWOOD}
        return d

    def get_current_indices(self)->dict[float]:
        d = {'burning_index':self.nfdrs4.BI,
             'energy_release_component':self.nfdrs4.ERC,
             'spread_component':self.nfdrs4.SC,
             'ignition_component':self.nfdrs4.IC,
             'growing_season_index':self.nfdrs4.m_GSI,
             'kb_drought_index':self.nfdrs4.KBDI}
        return d


    def process_df(self,df,
                   datetime_col:Union[int,str]="DateTime",
                   temp_col:Union[int,str]="Temperature(F)",
                   rh_col:Union[int,str]="RelativeHumidity(%)",
                   precip_col:Union[int,str]="Precipitation(in)",
                   srad_col:Union[int,str]="SolarRadiation(W/m2)",
                   windspeed_col:Union[int,str]="WindSpeed(mph)",
                   snowflag_col:Union[int,str]="SnowFlag")->'pd.DataFrame':

        """Process a dataframe or array containing weather data, e.g. in FW21 format.

        Specify column name (str) or position (int) for each required weather variable.

        Required columns:
            Year: year of observation (local time, not utc/zulu)
            Month: month of observation (local time, not utc/zulu)
            Day: day of observation (local time, not utc/zulu)
            Hour: hour of observation (local time, not utc/zulu)
            Temp: air temperature, degrees F
            RH: relative humidity, percent, expressed as value between 0 and 100
            PPTAmt: precipitation in this hour, inches
            SolarRad: solar radiation, watts per sq meter
            WS: wind speed, miles per hour
            SnowDay: boolean flag for snow day (check FW21 documentation)"""

        import pandas as pd
        import numpy as np

        try:
            dt_series = pd.to_datetime(df.iloc[:, datetime_col])
        except:
            dt_series = pd.to_datetime(df[datetime_col])

        try:
            wx = df.iloc[:, [temp_col, rh_col, precip_col, srad_col, windspeed_col, snowflag_col]]
        except:
            wx = df[[temp_col, rh_col, precip_col, srad_col, windspeed_col, snowflag_col]]

        try:
            try:
                wx_arr = wx.to_numpy()
            except:
                wx_arr = wx.to_array()
        except:
            wx_arr = np.array(wx)

        dt_arr = np.stack([
            dt_series.dt.year,
            dt_series.dt.month,
            dt_series.dt.day,
            dt_series.dt.hour,
        ]).T

        if not ((wx_arr.shape[0]==df.shape[0]) and (wx_arr.shape[1]==6) and
                (dt_arr.shape[0]==df.shape[0]) and (dt_arr.shape[1]==4)):
            raise TypeError("Could not cast input table to numpy arrays. Try casting to pandas.DataFrame first.")



        results_cols = ['dmc_1_hr', 'dmc_10_hr', 'dmc_100_hr', 'dmc_1000_hr', 'lmc_herb', 'lmc_woody',
                        'burning_index', 'energy_release_component', 'spread_component', 'ignition_component',
                        'growing_season_index','kb_drought_index']

        results = np.zeros([wx_arr.shape[0],len(results_cols)],float)

        for i in range(wx_arr.shape[0]):
            self.update_weather(dt_arr[i, 0], dt_arr[i, 1], dt_arr[i, 2], dt_arr[i, 3], wx_arr[i, 0], wx_arr[i, 1],
                                wx_arr[i, 2], wx_arr[i, 3], wx_arr[i, 4], wx_arr[i,5])

            results[i, :] = [self.nfdrs4.MC1, self.nfdrs4.MC10, self.nfdrs4.MC100, self.nfdrs4.MC1000,
                             self.nfdrs4.MCHERB, self.nfdrs4.MCWOOD,
                             self.nfdrs4.BI, self.nfdrs4.ERC, self.nfdrs4.SC, self.nfdrs4.IC,
                             self.nfdrs4.m_GSI,self.nfdrs4.KBDI]

        results = pd.DataFrame(results,columns=results_cols)

        return pd.concat([df,results],axis=1)

    @classmethod
    def init_from_config(cls, config: Union[dict[dict],str]):
        """Initialize NFDRS4py interface from configuration file or dictionary.

        First level keys must be 'general', 'liveFuelMoisture.defaults', 'gsi_opts', 'herb_opts', 'woody_opts',
        'deadFuelMoisture.defaults', '1hr_opts', '10hr_opts', '100hr_opts', '1000hr_opts', and/or 'customFuelModel'
        Second level keys must match variable names in associated nfdrs4py setter"""

        interface = cls()
        interface.set_from_config(config)
        return interface

def read_config(fp)->dict[dict]:
    """Read config file to dictionary. Must be formatted as nfdrs4 config or as .ini.

    Option names must match variable names of associated variables used in nfdrs4py setters. If format is .ini, sections
    must be 'general', 'liveFuelMoisture.defaults', 'gsi_opts', 'herb_opts', 'woody_opts', 'deadFuelMoisture.defaults',
    '1hr_opts', '10hr_opts', '100hr_opts', '1000hr_opts', and/or 'customFuelModel'"""

    import configparser
    import ast

    # Read text file, add initial section if needed, convert dictionaries and @copyFrom commands to be .ini friendly.
    lines = []
    with open(fp, encoding='utf8') as f:
        line = f.readline()
        if '[' not in line:
            lines.append('[general]\n')
        while line:
            if '{' in line:
                split = line.split('{')
                section = split[0].strip()
                lines.append(f'[{section}]\n')
                if len(split) > 0:
                    line = ' '.join(split[1:])
            line = line.replace('}', '')
            line = line.replace('@copyFrom', f'@copyFrom = ')
            lines.append(line)
            line = f.readline()

    # Send to configparser
    run_config = configparser.ConfigParser()
    run_config.read_string(''.join(lines))

    # Convert to dictionary
    d = {}
    for section in run_config.keys():
        d[section] = {}
        # Copy all key/value pairs from another section
        if '@copyfrom' in run_config[section].keys():
            copyfrom = run_config[section]['@copyfrom'].strip('\";\'')
            for item in d[copyfrom].items():
                d[section][item[0]] = item[1]

        for option in run_config[section].keys():
            if not '@copy' in option:
                # Clean and parse each value
                val = run_config[section][option]
                if type(val) is str:
                    val = val.replace('\"', '').replace(';', '').replace('\'', '')
                    vl = val.lower()
                    if vl == 'true' or vl == 't':
                        val = True
                    elif vl == 'false' or vl == 'f':
                        val = False
                    else:
                        try:
                            val = ast.literal_eval(val)
                        except (ValueError, SyntaxError):
                            val = str(val)

                d[section][option] = val

    return d



from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
from setuptools.command.build_py import build_py
from setuptools import find_packages
import numpy

# Define the SWIG extension
swig_extension = Extension(
    name='nfdrs4py._nfdrs4_bindings',  # Name of the Python package
    sources=['nfdrs4py/nfdrs4.i', 'lib/NFDRS4/src/deadfuelmoisture.cpp',  'lib/NFDRS4/src/livefuelmoisture.cpp',
             'lib/NFDRS4/src/dfmcalcstate.cpp', 'lib/NFDRS4/src/lfmcalcstate.cpp','lib/NFDRS4/src/nfdrs4calcstate.cpp',
             'lib/NFDRS4/src/nfdrs4.cpp', 'lib/NFDRS4/src/CNFDRSParams.cpp', 'lib/utctime/src/utctime.cpp', 'lib/time64/src/time64.c'],
    swig_opts=['-c++'],  # SWIG options
    language='c++',
    include_dirs=['lib/NFDRS4/include','lib/time64/include','lib/utctime/include',numpy.get_include()],  # C:/Users/john1/miniforge3/include/
    extra_compile_args=[],  # Additional compiler options
    extra_link_args=[],  # Additional linker options
)

class BuildPy(build_py):
    def run(self):
        self.run_command('build_ext')
        super(build_py, self).run()

setup(
    name='nfdrs4py',
    version='0.1.4',
    description='Python interface to NFDRS',
    url='https://github.com/j-tenny/NFDRS4py',
    ext_modules=[swig_extension],
    cmdclass={
        'build_py': BuildPy,
    },
    packages=find_packages(),
    #package_dir={'nfdrs4py': 'nfdrs4py'}
)


# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _nfdrs4_bindings
else:
    import _nfdrs4_bindings

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _nfdrs4_bindings.delete_SwigPyIterator

    def value(self):
        return _nfdrs4_bindings.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _nfdrs4_bindings.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _nfdrs4_bindings.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _nfdrs4_bindings.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _nfdrs4_bindings.SwigPyIterator_equal(self, x)

    def copy(self):
        return _nfdrs4_bindings.SwigPyIterator_copy(self)

    def next(self):
        return _nfdrs4_bindings.SwigPyIterator_next(self)

    def __next__(self):
        return _nfdrs4_bindings.SwigPyIterator___next__(self)

    def previous(self):
        return _nfdrs4_bindings.SwigPyIterator_previous(self)

    def advance(self, n):
        return _nfdrs4_bindings.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _nfdrs4_bindings.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _nfdrs4_bindings.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _nfdrs4_bindings.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _nfdrs4_bindings.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _nfdrs4_bindings.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _nfdrs4_bindings.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _nfdrs4_bindings:
_nfdrs4_bindings.SwigPyIterator_swigregister(SwigPyIterator)
DFM_State_None = _nfdrs4_bindings.DFM_State_None
DFM_State_Adsorption = _nfdrs4_bindings.DFM_State_Adsorption
DFM_State_Desorption = _nfdrs4_bindings.DFM_State_Desorption
DFM_State_Condensation1 = _nfdrs4_bindings.DFM_State_Condensation1
DFM_State_Condensation2 = _nfdrs4_bindings.DFM_State_Condensation2
DFM_State_Evaporation = _nfdrs4_bindings.DFM_State_Evaporation
DFM_State_Rainfall1 = _nfdrs4_bindings.DFM_State_Rainfall1
DFM_State_Rainfall2 = _nfdrs4_bindings.DFM_State_Rainfall2
DFM_State_Rainstorm = _nfdrs4_bindings.DFM_State_Rainstorm
DFM_State_Stagnation = _nfdrs4_bindings.DFM_State_Stagnation
DFM_State_Error = _nfdrs4_bindings.DFM_State_Error
class DeadFuelMoisture(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _nfdrs4_bindings.delete_DeadFuelMoisture

    def __init__(self, *args):
        _nfdrs4_bindings.DeadFuelMoisture_swiginit(self, _nfdrs4_bindings.new_DeadFuelMoisture(*args))

    def className(self):
        return _nfdrs4_bindings.DeadFuelMoisture_className(self)

    @staticmethod
    def createDeadFuelMoisture1(*args):
        return _nfdrs4_bindings.DeadFuelMoisture_createDeadFuelMoisture1(*args)

    @staticmethod
    def createDeadFuelMoisture10(*args):
        return _nfdrs4_bindings.DeadFuelMoisture_createDeadFuelMoisture10(*args)

    @staticmethod
    def createDeadFuelMoisture100(*args):
        return _nfdrs4_bindings.DeadFuelMoisture_createDeadFuelMoisture100(*args)

    @staticmethod
    def createDeadFuelMoisture1000(*args):
        return _nfdrs4_bindings.DeadFuelMoisture_createDeadFuelMoisture1000(*args)

    @staticmethod
    def deriveAdsorptionRate(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_deriveAdsorptionRate(radius)

    @staticmethod
    def deriveDiffusivitySteps(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_deriveDiffusivitySteps(radius)

    @staticmethod
    def deriveMoistureSteps(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_deriveMoistureSteps(radius)

    @staticmethod
    def derivePlanarHeatTransferRate(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_derivePlanarHeatTransferRate(radius)

    @staticmethod
    def deriveRainfallRunoffFactor(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_deriveRainfallRunoffFactor(radius)

    @staticmethod
    def deriveStickNodes(radius):
        return _nfdrs4_bindings.DeadFuelMoisture_deriveStickNodes(radius)

    @staticmethod
    def uniformRandom(min, max):
        return _nfdrs4_bindings.DeadFuelMoisture_uniformRandom(min, max)

    def initializeEnvironment(self, *args):
        return _nfdrs4_bindings.DeadFuelMoisture_initializeEnvironment(self, *args)

    def update(self, *args):
        return _nfdrs4_bindings.DeadFuelMoisture_update(self, *args)

    def zero(self):
        return _nfdrs4_bindings.DeadFuelMoisture_zero(self)

    def elapsedTime(self):
        return _nfdrs4_bindings.DeadFuelMoisture_elapsedTime(self)

    def initialized(self):
        return _nfdrs4_bindings.DeadFuelMoisture_initialized(self)

    def name(self):
        return _nfdrs4_bindings.DeadFuelMoisture_name(self)

    def meanMoisture(self):
        return _nfdrs4_bindings.DeadFuelMoisture_meanMoisture(self)

    def meanWtdMoisture(self):
        return _nfdrs4_bindings.DeadFuelMoisture_meanWtdMoisture(self)

    def medianRadialMoisture(self):
        return _nfdrs4_bindings.DeadFuelMoisture_medianRadialMoisture(self)

    def meanWtdTemperature(self):
        return _nfdrs4_bindings.DeadFuelMoisture_meanWtdTemperature(self)

    def pptRate(self):
        return _nfdrs4_bindings.DeadFuelMoisture_pptRate(self)

    def state(self):
        return _nfdrs4_bindings.DeadFuelMoisture_state(self)

    def stateName(self):
        return _nfdrs4_bindings.DeadFuelMoisture_stateName(self)

    def surfaceMoisture(self):
        return _nfdrs4_bindings.DeadFuelMoisture_surfaceMoisture(self)

    def surfaceTemperature(self):
        return _nfdrs4_bindings.DeadFuelMoisture_surfaceTemperature(self)

    def updates(self):
        return _nfdrs4_bindings.DeadFuelMoisture_updates(self)

    def adsorptionRate(self):
        return _nfdrs4_bindings.DeadFuelMoisture_adsorptionRate(self)

    def desorptionRate(self):
        return _nfdrs4_bindings.DeadFuelMoisture_desorptionRate(self)

    def diffusivitySteps(self):
        return _nfdrs4_bindings.DeadFuelMoisture_diffusivitySteps(self)

    def maximumLocalMoisture(self):
        return _nfdrs4_bindings.DeadFuelMoisture_maximumLocalMoisture(self)

    def moistureSteps(self):
        return _nfdrs4_bindings.DeadFuelMoisture_moistureSteps(self)

    def planarHeatTransferRate(self):
        return _nfdrs4_bindings.DeadFuelMoisture_planarHeatTransferRate(self)

    def rainfallRunoffFactor(self):
        return _nfdrs4_bindings.DeadFuelMoisture_rainfallRunoffFactor(self)

    def stickDensity(self):
        return _nfdrs4_bindings.DeadFuelMoisture_stickDensity(self)

    def stickLength(self):
        return _nfdrs4_bindings.DeadFuelMoisture_stickLength(self)

    def stickNodes(self):
        return _nfdrs4_bindings.DeadFuelMoisture_stickNodes(self)

    def waterFilmContribution(self):
        return _nfdrs4_bindings.DeadFuelMoisture_waterFilmContribution(self)

    def initializeStick(self):
        return _nfdrs4_bindings.DeadFuelMoisture_initializeStick(self)

    def setAdsorptionRate(self, adsorptionRate):
        return _nfdrs4_bindings.DeadFuelMoisture_setAdsorptionRate(self, adsorptionRate)

    def setAllowRainstorm(self, allow=True):
        return _nfdrs4_bindings.DeadFuelMoisture_setAllowRainstorm(self, allow)

    def setAllowRainfall2(self, allow=True):
        return _nfdrs4_bindings.DeadFuelMoisture_setAllowRainfall2(self, allow)

    def setDesorptionRate(self, desorptionRate=0.06):
        return _nfdrs4_bindings.DeadFuelMoisture_setDesorptionRate(self, desorptionRate)

    def setDiffusivitySteps(self, diffusivitySteps):
        return _nfdrs4_bindings.DeadFuelMoisture_setDiffusivitySteps(self, diffusivitySteps)

    def setMaximumLocalMoisture(self, localMaxMc=0.6):
        return _nfdrs4_bindings.DeadFuelMoisture_setMaximumLocalMoisture(self, localMaxMc)

    def setMoistureSteps(self, moistureSteps):
        return _nfdrs4_bindings.DeadFuelMoisture_setMoistureSteps(self, moistureSteps)

    def setPertubateColumn(self, pertubate=True):
        return _nfdrs4_bindings.DeadFuelMoisture_setPertubateColumn(self, pertubate)

    def setPlanarHeatTransferRate(self, planarHeatTransferRate):
        return _nfdrs4_bindings.DeadFuelMoisture_setPlanarHeatTransferRate(self, planarHeatTransferRate)

    def setRainfallRunoffFactor(self, rainfallRunoffFactor):
        return _nfdrs4_bindings.DeadFuelMoisture_setRainfallRunoffFactor(self, rainfallRunoffFactor)

    def setRandomSeed(self, randseed=0):
        return _nfdrs4_bindings.DeadFuelMoisture_setRandomSeed(self, randseed)

    def setRampRai0(self, ramp=True):
        return _nfdrs4_bindings.DeadFuelMoisture_setRampRai0(self, ramp)

    def setStickDensity(self, stickDensity=0.4):
        return _nfdrs4_bindings.DeadFuelMoisture_setStickDensity(self, stickDensity)

    def setStickLength(self, stickLength=41.0):
        return _nfdrs4_bindings.DeadFuelMoisture_setStickLength(self, stickLength)

    def setStickNodes(self, stickNodes=11):
        return _nfdrs4_bindings.DeadFuelMoisture_setStickNodes(self, stickNodes)

    def setWaterFilmContribution(self, waterFilm=0.0):
        return _nfdrs4_bindings.DeadFuelMoisture_setWaterFilmContribution(self, waterFilm)

    def setMoisture(self, initFM):
        return _nfdrs4_bindings.DeadFuelMoisture_setMoisture(self, initFM)

    def eqmc(self, fTemp, fRH):
        return _nfdrs4_bindings.DeadFuelMoisture_eqmc(self, fTemp, fRH)

    def initializeParameters(self, radius, name):
        return _nfdrs4_bindings.DeadFuelMoisture_initializeParameters(self, radius, name)

    def GetState(self):
        return _nfdrs4_bindings.DeadFuelMoisture_GetState(self)

    def SetState(self, state):
        return _nfdrs4_bindings.DeadFuelMoisture_SetState(self, state)

# Register DeadFuelMoisture in _nfdrs4_bindings:
_nfdrs4_bindings.DeadFuelMoisture_swigregister(DeadFuelMoisture)
NOVALUE = _nfdrs4_bindings.NOVALUE
RADPERDAY = _nfdrs4_bindings.RADPERDAY
RADPERDEG = _nfdrs4_bindings.RADPERDEG
MINDECL = _nfdrs4_bindings.MINDECL
SECPERRAD = _nfdrs4_bindings.SECPERRAD
DAYSOFF = _nfdrs4_bindings.DAYSOFF
class LiveFuelMoisture(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.LiveFuelMoisture_swiginit(self, _nfdrs4_bindings.new_LiveFuelMoisture(*args))

    def Initialize(self, Lat, IsHerb, IsAnnual):
        return _nfdrs4_bindings.LiveFuelMoisture_Initialize(self, Lat, IsHerb, IsAnnual)

    def SetLimits(self, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9):
        return _nfdrs4_bindings.LiveFuelMoisture_SetLimits(self, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9)

    def Update(self, TempF, MaxTempF, MinTempF, RH, minRH, Jday, RTPrcp, thisTime):
        return _nfdrs4_bindings.LiveFuelMoisture_Update(self, TempF, MaxTempF, MinTempF, RH, minRH, Jday, RTPrcp, thisTime)

    def SetMAPeriod(self, MAPeriod):
        return _nfdrs4_bindings.LiveFuelMoisture_SetMAPeriod(self, MAPeriod)

    def SetLFMParameters(self, MaxGSI, GreenupThreshold, MinLFMVal, MaxLFMVal):
        return _nfdrs4_bindings.LiveFuelMoisture_SetLFMParameters(self, MaxGSI, GreenupThreshold, MinLFMVal, MaxLFMVal)

    def GetLFMParameters(self, MaxGSI, GreenupThreshold, MinLFMVal, MaxLFMVal):
        return _nfdrs4_bindings.LiveFuelMoisture_GetLFMParameters(self, MaxGSI, GreenupThreshold, MinLFMVal, MaxLFMVal)

    def SetNumPrecipDays(self, numDays):
        return _nfdrs4_bindings.LiveFuelMoisture_SetNumPrecipDays(self, numDays)

    def GetNumPrecipDays(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetNumPrecipDays(self)

    def GetMoisture(self, SnowDay=False):
        return _nfdrs4_bindings.LiveFuelMoisture_GetMoisture(self, SnowDay)

    def CalcRunningAvgGSI(self):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcRunningAvgGSI(self)

    def CalcRunningAvgHerbFM(self, SnowDay=False):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcRunningAvgHerbFM(self, SnowDay)

    def ResetHerbState(self):
        return _nfdrs4_bindings.LiveFuelMoisture_ResetHerbState(self)

    def CalcRunningAvgWoodyFM(self, SnowDay=False):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcRunningAvgWoodyFM(self, SnowDay)

    def CalcGSI(self, minRH, maxTempF, minTempF, RTPrcp, lat, doy):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcGSI(self, minRH, maxTempF, minTempF, RTPrcp, lat, doy)

    def CalcGSI_VPDAvg(self, RH, TempF, maxTempF, minTempF, RTPrcp, lat, doy):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcGSI_VPDAvg(self, RH, TempF, maxTempF, minTempF, RTPrcp, lat, doy)

    def GetTminInd(self, Tmin):
        return _nfdrs4_bindings.LiveFuelMoisture_GetTminInd(self, Tmin)

    def GetVPDInd(self, VPD):
        return _nfdrs4_bindings.LiveFuelMoisture_GetVPDInd(self, VPD)

    def GetDaylInd(self, Dayl):
        return _nfdrs4_bindings.LiveFuelMoisture_GetDaylInd(self, Dayl)

    def GetPrcpInd(self, RTPrcp):
        return _nfdrs4_bindings.LiveFuelMoisture_GetPrcpInd(self, RTPrcp)

    def CalcDayl(self, lat, yday):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcDayl(self, lat, yday)

    def CalcVPDavg(self, TempDewF, TempAvgF):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcVPDavg(self, TempDewF, TempAvgF)

    def CalcVPD(self, RH, TempF):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcVPD(self, RH, TempF)

    def CalcDPT(self, tempF, RH):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcDPT(self, tempF, RH)

    def CalcVP(self, tempF):
        return _nfdrs4_bindings.LiveFuelMoisture_CalcVP(self, tempF)

    def GetMaxGSI(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetMaxGSI(self)

    def GetGreenupThreshold(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetGreenupThreshold(self)

    def GetMinLFMVal(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetMinLFMVal(self)

    def GetMaxLFMVal(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetMaxLFMVal(self)

    def SetUseVPDAvg(self, set):
        return _nfdrs4_bindings.LiveFuelMoisture_SetUseVPDAvg(self, set)

    def GetUseVPDAvg(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetUseVPDAvg(self)

    def GetIsAnnual(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetIsAnnual(self)

    def GetState(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetState(self)

    def SetState(self, state):
        return _nfdrs4_bindings.LiveFuelMoisture_SetState(self, state)

    def SetUseRTPrecip(self, set):
        return _nfdrs4_bindings.LiveFuelMoisture_SetUseRTPrecip(self, set)

    def GetUseRTPrecip(self):
        return _nfdrs4_bindings.LiveFuelMoisture_GetUseRTPrecip(self)
    __swig_destroy__ = _nfdrs4_bindings.delete_LiveFuelMoisture

# Register LiveFuelMoisture in _nfdrs4_bindings:
_nfdrs4_bindings.LiveFuelMoisture_swigregister(LiveFuelMoisture)
class DFMCalcState(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.DFMCalcState_swiginit(self, _nfdrs4_bindings.new_DFMCalcState(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_DFMCalcState

    def ReadState(self, _in):
        return _nfdrs4_bindings.DFMCalcState_ReadState(self, _in)

    def SaveState(self, out):
        return _nfdrs4_bindings.DFMCalcState_SaveState(self, out)
    m_JDay = property(_nfdrs4_bindings.DFMCalcState_m_JDay_get, _nfdrs4_bindings.DFMCalcState_m_JDay_set)
    m_Year = property(_nfdrs4_bindings.DFMCalcState_m_Year_get, _nfdrs4_bindings.DFMCalcState_m_Year_set)
    m_Month = property(_nfdrs4_bindings.DFMCalcState_m_Month_get, _nfdrs4_bindings.DFMCalcState_m_Month_set)
    m_Day = property(_nfdrs4_bindings.DFMCalcState_m_Day_get, _nfdrs4_bindings.DFMCalcState_m_Day_set)
    m_Hour = property(_nfdrs4_bindings.DFMCalcState_m_Hour_get, _nfdrs4_bindings.DFMCalcState_m_Hour_set)
    m_Min = property(_nfdrs4_bindings.DFMCalcState_m_Min_get, _nfdrs4_bindings.DFMCalcState_m_Min_set)
    m_Sec = property(_nfdrs4_bindings.DFMCalcState_m_Sec_get, _nfdrs4_bindings.DFMCalcState_m_Sec_set)
    m_obstime = property(_nfdrs4_bindings.DFMCalcState_m_obstime_get, _nfdrs4_bindings.DFMCalcState_m_obstime_set)
    m_bp1 = property(_nfdrs4_bindings.DFMCalcState_m_bp1_get, _nfdrs4_bindings.DFMCalcState_m_bp1_set)
    m_et = property(_nfdrs4_bindings.DFMCalcState_m_et_get, _nfdrs4_bindings.DFMCalcState_m_et_set)
    m_ha1 = property(_nfdrs4_bindings.DFMCalcState_m_ha1_get, _nfdrs4_bindings.DFMCalcState_m_ha1_set)
    m_rc1 = property(_nfdrs4_bindings.DFMCalcState_m_rc1_get, _nfdrs4_bindings.DFMCalcState_m_rc1_set)
    m_sv1 = property(_nfdrs4_bindings.DFMCalcState_m_sv1_get, _nfdrs4_bindings.DFMCalcState_m_sv1_set)
    m_ta1 = property(_nfdrs4_bindings.DFMCalcState_m_ta1_get, _nfdrs4_bindings.DFMCalcState_m_ta1_set)
    m_hf = property(_nfdrs4_bindings.DFMCalcState_m_hf_get, _nfdrs4_bindings.DFMCalcState_m_hf_set)
    m_wsa = property(_nfdrs4_bindings.DFMCalcState_m_wsa_get, _nfdrs4_bindings.DFMCalcState_m_wsa_set)
    m_rdur = property(_nfdrs4_bindings.DFMCalcState_m_rdur_get, _nfdrs4_bindings.DFMCalcState_m_rdur_set)
    m_ra1 = property(_nfdrs4_bindings.DFMCalcState_m_ra1_get, _nfdrs4_bindings.DFMCalcState_m_ra1_set)
    m_nodes = property(_nfdrs4_bindings.DFMCalcState_m_nodes_get, _nfdrs4_bindings.DFMCalcState_m_nodes_set)
    m_t = property(_nfdrs4_bindings.DFMCalcState_m_t_get, _nfdrs4_bindings.DFMCalcState_m_t_set)
    m_s = property(_nfdrs4_bindings.DFMCalcState_m_s_get, _nfdrs4_bindings.DFMCalcState_m_s_set)
    m_d = property(_nfdrs4_bindings.DFMCalcState_m_d_get, _nfdrs4_bindings.DFMCalcState_m_d_set)
    m_w = property(_nfdrs4_bindings.DFMCalcState_m_w_get, _nfdrs4_bindings.DFMCalcState_m_w_set)

# Register DFMCalcState in _nfdrs4_bindings:
_nfdrs4_bindings.DFMCalcState_swigregister(DFMCalcState)
class LFMCalcState(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.LFMCalcState_swiginit(self, _nfdrs4_bindings.new_LFMCalcState(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_LFMCalcState

    def ReadState(self, _in):
        return _nfdrs4_bindings.LFMCalcState_ReadState(self, _in)

    def SaveState(self, out):
        return _nfdrs4_bindings.LFMCalcState_SaveState(self, out)
    m_lastUpdateTime = property(_nfdrs4_bindings.LFMCalcState_m_lastUpdateTime_get, _nfdrs4_bindings.LFMCalcState_m_lastUpdateTime_set)
    m_UseVPDAvg = property(_nfdrs4_bindings.LFMCalcState_m_UseVPDAvg_get, _nfdrs4_bindings.LFMCalcState_m_UseVPDAvg_set)
    m_IsHerb = property(_nfdrs4_bindings.LFMCalcState_m_IsHerb_get, _nfdrs4_bindings.LFMCalcState_m_IsHerb_set)
    m_IsAnnual = property(_nfdrs4_bindings.LFMCalcState_m_IsAnnual_get, _nfdrs4_bindings.LFMCalcState_m_IsAnnual_set)
    m_LFIdaysAvg = property(_nfdrs4_bindings.LFMCalcState_m_LFIdaysAvg_get, _nfdrs4_bindings.LFMCalcState_m_LFIdaysAvg_set)
    m_nDaysPrecip = property(_nfdrs4_bindings.LFMCalcState_m_nDaysPrecip_get, _nfdrs4_bindings.LFMCalcState_m_nDaysPrecip_set)
    m_Lat = property(_nfdrs4_bindings.LFMCalcState_m_Lat_get, _nfdrs4_bindings.LFMCalcState_m_Lat_set)
    m_TminMin = property(_nfdrs4_bindings.LFMCalcState_m_TminMin_get, _nfdrs4_bindings.LFMCalcState_m_TminMin_set)
    m_TminMax = property(_nfdrs4_bindings.LFMCalcState_m_TminMax_get, _nfdrs4_bindings.LFMCalcState_m_TminMax_set)
    m_VPDMin = property(_nfdrs4_bindings.LFMCalcState_m_VPDMin_get, _nfdrs4_bindings.LFMCalcState_m_VPDMin_set)
    m_VPDMax = property(_nfdrs4_bindings.LFMCalcState_m_VPDMax_get, _nfdrs4_bindings.LFMCalcState_m_VPDMax_set)
    m_DaylenMin = property(_nfdrs4_bindings.LFMCalcState_m_DaylenMin_get, _nfdrs4_bindings.LFMCalcState_m_DaylenMin_set)
    m_DaylenMax = property(_nfdrs4_bindings.LFMCalcState_m_DaylenMax_get, _nfdrs4_bindings.LFMCalcState_m_DaylenMax_set)
    m_MaxGSI = property(_nfdrs4_bindings.LFMCalcState_m_MaxGSI_get, _nfdrs4_bindings.LFMCalcState_m_MaxGSI_set)
    m_GreenupThreshold = property(_nfdrs4_bindings.LFMCalcState_m_GreenupThreshold_get, _nfdrs4_bindings.LFMCalcState_m_GreenupThreshold_set)
    m_MaxLFMVal = property(_nfdrs4_bindings.LFMCalcState_m_MaxLFMVal_get, _nfdrs4_bindings.LFMCalcState_m_MaxLFMVal_set)
    m_MinLFMVal = property(_nfdrs4_bindings.LFMCalcState_m_MinLFMVal_get, _nfdrs4_bindings.LFMCalcState_m_MinLFMVal_set)
    m_Slope = property(_nfdrs4_bindings.LFMCalcState_m_Slope_get, _nfdrs4_bindings.LFMCalcState_m_Slope_set)
    m_Intercept = property(_nfdrs4_bindings.LFMCalcState_m_Intercept_get, _nfdrs4_bindings.LFMCalcState_m_Intercept_set)
    m_hasGreenedUpThisYear = property(_nfdrs4_bindings.LFMCalcState_m_hasGreenedUpThisYear_get, _nfdrs4_bindings.LFMCalcState_m_hasGreenedUpThisYear_set)
    m_hasExceeded120ThisYear = property(_nfdrs4_bindings.LFMCalcState_m_hasExceeded120ThisYear_get, _nfdrs4_bindings.LFMCalcState_m_hasExceeded120ThisYear_set)
    m_canIncreaseHerb = property(_nfdrs4_bindings.LFMCalcState_m_canIncreaseHerb_get, _nfdrs4_bindings.LFMCalcState_m_canIncreaseHerb_set)
    lastHerbFM = property(_nfdrs4_bindings.LFMCalcState_lastHerbFM_get, _nfdrs4_bindings.LFMCalcState_lastHerbFM_set)
    m_useRTPrecip = property(_nfdrs4_bindings.LFMCalcState_m_useRTPrecip_get, _nfdrs4_bindings.LFMCalcState_m_useRTPrecip_set)
    m_pcpMin = property(_nfdrs4_bindings.LFMCalcState_m_pcpMin_get, _nfdrs4_bindings.LFMCalcState_m_pcpMin_set)
    m_pcpMax = property(_nfdrs4_bindings.LFMCalcState_m_pcpMax_get, _nfdrs4_bindings.LFMCalcState_m_pcpMax_set)
    m_qGSI = property(_nfdrs4_bindings.LFMCalcState_m_qGSI_get, _nfdrs4_bindings.LFMCalcState_m_qGSI_set)

# Register LFMCalcState in _nfdrs4_bindings:
_nfdrs4_bindings.LFMCalcState_swigregister(LFMCalcState)
class NFDRS4State(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.NFDRS4State_swiginit(self, _nfdrs4_bindings.new_NFDRS4State(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_NFDRS4State

    def LoadState(self, fileName):
        return _nfdrs4_bindings.NFDRS4State_LoadState(self, fileName)

    def SaveState(self, fileName):
        return _nfdrs4_bindings.NFDRS4State_SaveState(self, fileName)
    m_NFDRSVersion = property(_nfdrs4_bindings.NFDRS4State_m_NFDRSVersion_get, _nfdrs4_bindings.NFDRS4State_m_NFDRSVersion_set)
    fm1State = property(_nfdrs4_bindings.NFDRS4State_fm1State_get, _nfdrs4_bindings.NFDRS4State_fm1State_set)
    fm10State = property(_nfdrs4_bindings.NFDRS4State_fm10State_get, _nfdrs4_bindings.NFDRS4State_fm10State_set)
    fm100State = property(_nfdrs4_bindings.NFDRS4State_fm100State_get, _nfdrs4_bindings.NFDRS4State_fm100State_set)
    fm1000State = property(_nfdrs4_bindings.NFDRS4State_fm1000State_get, _nfdrs4_bindings.NFDRS4State_fm1000State_set)
    herbState = property(_nfdrs4_bindings.NFDRS4State_herbState_get, _nfdrs4_bindings.NFDRS4State_herbState_set)
    woodyState = property(_nfdrs4_bindings.NFDRS4State_woodyState_get, _nfdrs4_bindings.NFDRS4State_woodyState_set)
    m_Lat = property(_nfdrs4_bindings.NFDRS4State_m_Lat_get, _nfdrs4_bindings.NFDRS4State_m_Lat_set)
    m_YesterdayJDay = property(_nfdrs4_bindings.NFDRS4State_m_YesterdayJDay_get, _nfdrs4_bindings.NFDRS4State_m_YesterdayJDay_set)
    m_SlopeClass = property(_nfdrs4_bindings.NFDRS4State_m_SlopeClass_get, _nfdrs4_bindings.NFDRS4State_m_SlopeClass_set)
    m_FuelModel = property(_nfdrs4_bindings.NFDRS4State_m_FuelModel_get, _nfdrs4_bindings.NFDRS4State_m_FuelModel_set)
    m_MC1 = property(_nfdrs4_bindings.NFDRS4State_m_MC1_get, _nfdrs4_bindings.NFDRS4State_m_MC1_set)
    m_MC10 = property(_nfdrs4_bindings.NFDRS4State_m_MC10_get, _nfdrs4_bindings.NFDRS4State_m_MC10_set)
    m_MC100 = property(_nfdrs4_bindings.NFDRS4State_m_MC100_get, _nfdrs4_bindings.NFDRS4State_m_MC100_set)
    m_MC1000 = property(_nfdrs4_bindings.NFDRS4State_m_MC1000_get, _nfdrs4_bindings.NFDRS4State_m_MC1000_set)
    m_MCWOOD = property(_nfdrs4_bindings.NFDRS4State_m_MCWOOD_get, _nfdrs4_bindings.NFDRS4State_m_MCWOOD_set)
    m_MCHERB = property(_nfdrs4_bindings.NFDRS4State_m_MCHERB_get, _nfdrs4_bindings.NFDRS4State_m_MCHERB_set)
    m_PrevYear = property(_nfdrs4_bindings.NFDRS4State_m_PrevYear_get, _nfdrs4_bindings.NFDRS4State_m_PrevYear_set)
    m_KBDI = property(_nfdrs4_bindings.NFDRS4State_m_KBDI_get, _nfdrs4_bindings.NFDRS4State_m_KBDI_set)
    m_YKBDI = property(_nfdrs4_bindings.NFDRS4State_m_YKBDI_get, _nfdrs4_bindings.NFDRS4State_m_YKBDI_set)
    m_StartKBDI = property(_nfdrs4_bindings.NFDRS4State_m_StartKBDI_get, _nfdrs4_bindings.NFDRS4State_m_StartKBDI_set)
    m_KBDIThreshold = property(_nfdrs4_bindings.NFDRS4State_m_KBDIThreshold_get, _nfdrs4_bindings.NFDRS4State_m_KBDIThreshold_set)
    m_CummPrecip = property(_nfdrs4_bindings.NFDRS4State_m_CummPrecip_get, _nfdrs4_bindings.NFDRS4State_m_CummPrecip_set)
    m_AvgPrecip = property(_nfdrs4_bindings.NFDRS4State_m_AvgPrecip_get, _nfdrs4_bindings.NFDRS4State_m_AvgPrecip_set)
    m_UseLoadTransfer = property(_nfdrs4_bindings.NFDRS4State_m_UseLoadTransfer_get, _nfdrs4_bindings.NFDRS4State_m_UseLoadTransfer_set)
    m_UseCuring = property(_nfdrs4_bindings.NFDRS4State_m_UseCuring_get, _nfdrs4_bindings.NFDRS4State_m_UseCuring_set)
    m_FuelTemperature = property(_nfdrs4_bindings.NFDRS4State_m_FuelTemperature_get, _nfdrs4_bindings.NFDRS4State_m_FuelTemperature_set)
    m_BI = property(_nfdrs4_bindings.NFDRS4State_m_BI_get, _nfdrs4_bindings.NFDRS4State_m_BI_set)
    m_ERC = property(_nfdrs4_bindings.NFDRS4State_m_ERC_get, _nfdrs4_bindings.NFDRS4State_m_ERC_set)
    m_SC = property(_nfdrs4_bindings.NFDRS4State_m_SC_get, _nfdrs4_bindings.NFDRS4State_m_SC_set)
    m_IC = property(_nfdrs4_bindings.NFDRS4State_m_IC_get, _nfdrs4_bindings.NFDRS4State_m_IC_set)
    m_GSI = property(_nfdrs4_bindings.NFDRS4State_m_GSI_get, _nfdrs4_bindings.NFDRS4State_m_GSI_set)
    m_nConsectiveSnowDays = property(_nfdrs4_bindings.NFDRS4State_m_nConsectiveSnowDays_get, _nfdrs4_bindings.NFDRS4State_m_nConsectiveSnowDays_set)
    m_lastUtcUpdateTime = property(_nfdrs4_bindings.NFDRS4State_m_lastUtcUpdateTime_get, _nfdrs4_bindings.NFDRS4State_m_lastUtcUpdateTime_set)
    m_lastDailyUpdateTime = property(_nfdrs4_bindings.NFDRS4State_m_lastDailyUpdateTime_get, _nfdrs4_bindings.NFDRS4State_m_lastDailyUpdateTime_set)
    m_qPrecip = property(_nfdrs4_bindings.NFDRS4State_m_qPrecip_get, _nfdrs4_bindings.NFDRS4State_m_qPrecip_set)
    m_qHourlyPrecip = property(_nfdrs4_bindings.NFDRS4State_m_qHourlyPrecip_get, _nfdrs4_bindings.NFDRS4State_m_qHourlyPrecip_set)
    m_qHourlyTemp = property(_nfdrs4_bindings.NFDRS4State_m_qHourlyTemp_get, _nfdrs4_bindings.NFDRS4State_m_qHourlyTemp_set)
    m_qHourlyRH = property(_nfdrs4_bindings.NFDRS4State_m_qHourlyRH_get, _nfdrs4_bindings.NFDRS4State_m_qHourlyRH_set)

# Register NFDRS4State in _nfdrs4_bindings:
_nfdrs4_bindings.NFDRS4State_swigregister(NFDRS4State)
class CFuelModelParams(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.CFuelModelParams_swiginit(self, _nfdrs4_bindings.new_CFuelModelParams(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_CFuelModelParams

    def getFuelModel(self):
        return _nfdrs4_bindings.CFuelModelParams_getFuelModel(self)

    def getDescription(self):
        return _nfdrs4_bindings.CFuelModelParams_getDescription(self)

    def getSG1(self):
        return _nfdrs4_bindings.CFuelModelParams_getSG1(self)

    def getSG10(self):
        return _nfdrs4_bindings.CFuelModelParams_getSG10(self)

    def getSG100(self):
        return _nfdrs4_bindings.CFuelModelParams_getSG100(self)

    def getSG1000(self):
        return _nfdrs4_bindings.CFuelModelParams_getSG1000(self)

    def getSGHerb(self):
        return _nfdrs4_bindings.CFuelModelParams_getSGHerb(self)

    def getSGWood(self):
        return _nfdrs4_bindings.CFuelModelParams_getSGWood(self)

    def getL1(self):
        return _nfdrs4_bindings.CFuelModelParams_getL1(self)

    def getL10(self):
        return _nfdrs4_bindings.CFuelModelParams_getL10(self)

    def getL100(self):
        return _nfdrs4_bindings.CFuelModelParams_getL100(self)

    def getL1000(self):
        return _nfdrs4_bindings.CFuelModelParams_getL1000(self)

    def getLHerb(self):
        return _nfdrs4_bindings.CFuelModelParams_getLHerb(self)

    def getLWood(self):
        return _nfdrs4_bindings.CFuelModelParams_getLWood(self)

    def getDepth(self):
        return _nfdrs4_bindings.CFuelModelParams_getDepth(self)

    def getMXD(self):
        return _nfdrs4_bindings.CFuelModelParams_getMXD(self)

    def getHD(self):
        return _nfdrs4_bindings.CFuelModelParams_getHD(self)

    def getSCM(self):
        return _nfdrs4_bindings.CFuelModelParams_getSCM(self)

    def getLDrought(self):
        return _nfdrs4_bindings.CFuelModelParams_getLDrought(self)

    def getWNDFC(self):
        return _nfdrs4_bindings.CFuelModelParams_getWNDFC(self)

    def setFuelModel(self, fm):
        return _nfdrs4_bindings.CFuelModelParams_setFuelModel(self, fm)

    def setDescription(self, description):
        return _nfdrs4_bindings.CFuelModelParams_setDescription(self, description)

    def setSG1(self, sg1):
        return _nfdrs4_bindings.CFuelModelParams_setSG1(self, sg1)

    def setSG10(self, sg10):
        return _nfdrs4_bindings.CFuelModelParams_setSG10(self, sg10)

    def setSG100(self, sg100):
        return _nfdrs4_bindings.CFuelModelParams_setSG100(self, sg100)

    def setSG1000(self, sg1000):
        return _nfdrs4_bindings.CFuelModelParams_setSG1000(self, sg1000)

    def setSGHerb(self, sgHerb):
        return _nfdrs4_bindings.CFuelModelParams_setSGHerb(self, sgHerb)

    def setSGWood(self, sgWood):
        return _nfdrs4_bindings.CFuelModelParams_setSGWood(self, sgWood)

    def setL1(self, l1):
        return _nfdrs4_bindings.CFuelModelParams_setL1(self, l1)

    def setL10(self, l10):
        return _nfdrs4_bindings.CFuelModelParams_setL10(self, l10)

    def setL100(self, l100):
        return _nfdrs4_bindings.CFuelModelParams_setL100(self, l100)

    def setL1000(self, l1000):
        return _nfdrs4_bindings.CFuelModelParams_setL1000(self, l1000)

    def setLHerb(self, lHerb):
        return _nfdrs4_bindings.CFuelModelParams_setLHerb(self, lHerb)

    def setLWood(self, lWood):
        return _nfdrs4_bindings.CFuelModelParams_setLWood(self, lWood)

    def setDepth(self, depth):
        return _nfdrs4_bindings.CFuelModelParams_setDepth(self, depth)

    def setMXD(self, mxd):
        return _nfdrs4_bindings.CFuelModelParams_setMXD(self, mxd)

    def setHD(self, hd):
        return _nfdrs4_bindings.CFuelModelParams_setHD(self, hd)

    def setSCM(self, scm):
        return _nfdrs4_bindings.CFuelModelParams_setSCM(self, scm)

    def setLDrought(self, ldrought):
        return _nfdrs4_bindings.CFuelModelParams_setLDrought(self, ldrought)

    def setWNDFC(self, wndfc):
        return _nfdrs4_bindings.CFuelModelParams_setWNDFC(self, wndfc)

# Register CFuelModelParams in _nfdrs4_bindings:
_nfdrs4_bindings.CFuelModelParams_swigregister(CFuelModelParams)
class NFDRS4(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.NFDRS4_swiginit(self, _nfdrs4_bindings.new_NFDRS4(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_NFDRS4

    def CreateFuelModels(self):
        return _nfdrs4_bindings.NFDRS4_CreateFuelModels(self)

    def Init(self, Lat, FuelModel, SlopeClass, AvgAnnPrecip, LT, Cure, isAnnual, kbdiThreshold, RegObsHour=13, isReinit=False):
        return _nfdrs4_bindings.NFDRS4_Init(self, Lat, FuelModel, SlopeClass, AvgAnnPrecip, LT, Cure, isAnnual, kbdiThreshold, RegObsHour, isReinit)

    def Update(self, *args):
        return _nfdrs4_bindings.NFDRS4_Update(self, *args)

    def UpdateDaily(self, Year, Month, Day, Julian, Temp, MinTemp, MaxTemp, RH, MinRH, pcp24, WS, fMC1, fMC10, fMC100, fMC1000, fuelTemp, SnowDay):
        return _nfdrs4_bindings.NFDRS4_UpdateDaily(self, Year, Month, Day, Julian, Temp, MinTemp, MaxTemp, RH, MinRH, pcp24, WS, fMC1, fMC10, fMC100, fMC1000, fuelTemp, SnowDay)

    def iSetFuelModel(self, cFM):
        return _nfdrs4_bindings.NFDRS4_iSetFuelModel(self, cFM)

    def iSetFuelMoistures(self, fMC1, fMC10, fMC100, fMC1000, fMCWood, fMCHerb, fuelTempC):
        return _nfdrs4_bindings.NFDRS4_iSetFuelMoistures(self, fMC1, fMC10, fMC100, fMC1000, fMCWood, fMCHerb, fuelTempC)

    def iCalcIndexes(self, iWS, iSlopeCls, fSC, fERC, fBI, fIC, fGSI=-999, fKBDI=-999):
        return _nfdrs4_bindings.NFDRS4_iCalcIndexes(self, iWS, iSlopeCls, fSC, fERC, fBI, fIC, fGSI, fKBDI)

    def iCalcKBDI(self, fPrecipAmt, iMaxTemp, fCummPrecip, iYKBDI, fAvgPrecip):
        return _nfdrs4_bindings.NFDRS4_iCalcKBDI(self, fPrecipAmt, iMaxTemp, fCummPrecip, iYKBDI, fAvgPrecip)

    def Cure(self, fGSI=-999, fGreenupThreshold=0.5, fGSIMax=1.0):
        return _nfdrs4_bindings.NFDRS4_Cure(self, fGSI, fGreenupThreshold, fGSIMax)

    def SetGSIParams(self, MaxGSI, GreenupThreshold, TminMin=-2.0, TminMax=5.0, VPDMin=900, VPDMax=4100, DaylMin=36000, DaylMax=39600, MAPeriod=21, UseVPDAvg=False, nPrecipDays=30, rtPrecipMin=0.5, rtPrecipMax=1.5, UseRTPrecip=False):
        return _nfdrs4_bindings.NFDRS4_SetGSIParams(self, MaxGSI, GreenupThreshold, TminMin, TminMax, VPDMin, VPDMax, DaylMin, DaylMax, MAPeriod, UseVPDAvg, nPrecipDays, rtPrecipMin, rtPrecipMax, UseRTPrecip)

    def SetHerbGSIparams(self, MaxGSI, GreenupThreshold, TminMin=-2.0, TminMax=5.0, VPDMin=900, VPDMax=4100, DaylMin=36000, DaylMax=39600, MAPeriod=21, UseVPDAvg=False, nPrecipDays=30, rtPrecipMin=0.5, rtPrecipMax=1.5, UseRTPrecip=False, herbMin=30.0, herbMax=250.0):
        return _nfdrs4_bindings.NFDRS4_SetHerbGSIparams(self, MaxGSI, GreenupThreshold, TminMin, TminMax, VPDMin, VPDMax, DaylMin, DaylMax, MAPeriod, UseVPDAvg, nPrecipDays, rtPrecipMin, rtPrecipMax, UseRTPrecip, herbMin, herbMax)

    def SetWoodyGSIparams(self, MaxGSI, GreenupThreshold, TminMin=-2.0, TminMax=5.0, VPDMin=900, VPDMax=4100, DaylMin=36000, DaylMax=39600, MAPeriod=21, UseVPDAvg=False, nPrecipDays=30, rtPrecipMin=0.5, rtPrecipMax=1.5, UseRTPrecip=False, woodyMin=60.0, woodyMax=200.0):
        return _nfdrs4_bindings.NFDRS4_SetWoodyGSIparams(self, MaxGSI, GreenupThreshold, TminMin, TminMax, VPDMin, VPDMax, DaylMin, DaylMax, MAPeriod, UseVPDAvg, nPrecipDays, rtPrecipMin, rtPrecipMax, UseRTPrecip, woodyMin, woodyMax)

    def SetOneHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_SetOneHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate)

    def SetTenHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_SetTenHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate)

    def SetHundredHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_SetHundredHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate)

    def SetThousandHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_SetThousandHourParams(self, radius, adsorptionRate, maxLocalMoisture, stickDensity, desorptionRate)

    def Set1HourRadius(self, radius):
        return _nfdrs4_bindings.NFDRS4_Set1HourRadius(self, radius)

    def Set1HourAdsorptionRate(self, adsorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set1HourAdsorptionRate(self, adsorptionRate)

    def Set1HourStickDensity(self, stickDensity):
        return _nfdrs4_bindings.NFDRS4_Set1HourStickDensity(self, stickDensity)

    def Set1HourMaxLocalMoisture(self, maxLocalMoisture):
        return _nfdrs4_bindings.NFDRS4_Set1HourMaxLocalMoisture(self, maxLocalMoisture)

    def Set1HourDesorptionRate(self, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set1HourDesorptionRate(self, desorptionRate)

    def Set10HourRadius(self, radius):
        return _nfdrs4_bindings.NFDRS4_Set10HourRadius(self, radius)

    def Set10HourAdsorptionRate(self, adsorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set10HourAdsorptionRate(self, adsorptionRate)

    def Set10HourStickDensity(self, stickDensity):
        return _nfdrs4_bindings.NFDRS4_Set10HourStickDensity(self, stickDensity)

    def Set10HourMaxLocalMoisture(self, maxLocalMoisture):
        return _nfdrs4_bindings.NFDRS4_Set10HourMaxLocalMoisture(self, maxLocalMoisture)

    def Set10HourDesorptionRate(self, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set10HourDesorptionRate(self, desorptionRate)

    def Set100HourRadius(self, radius):
        return _nfdrs4_bindings.NFDRS4_Set100HourRadius(self, radius)

    def Set100HourAdsorptionRate(self, adsorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set100HourAdsorptionRate(self, adsorptionRate)

    def Set100HourStickDensity(self, stickDensity):
        return _nfdrs4_bindings.NFDRS4_Set100HourStickDensity(self, stickDensity)

    def Set100HourMaxLocalMoisture(self, maxLocalMoisture):
        return _nfdrs4_bindings.NFDRS4_Set100HourMaxLocalMoisture(self, maxLocalMoisture)

    def Set100HourDesorptionRate(self, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set100HourDesorptionRate(self, desorptionRate)

    def Set1000HourRadius(self, radius):
        return _nfdrs4_bindings.NFDRS4_Set1000HourRadius(self, radius)

    def Set1000HourAdsorptionRate(self, adsorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set1000HourAdsorptionRate(self, adsorptionRate)

    def Set1000HourStickDensity(self, stickDensity):
        return _nfdrs4_bindings.NFDRS4_Set1000HourStickDensity(self, stickDensity)

    def Set1000HourMaxLocalMoisture(self, maxLocalMoisture):
        return _nfdrs4_bindings.NFDRS4_Set1000HourMaxLocalMoisture(self, maxLocalMoisture)

    def Set1000HourDesorptionRate(self, desorptionRate):
        return _nfdrs4_bindings.NFDRS4_Set1000HourDesorptionRate(self, desorptionRate)

    def SetStartKBDI(self, sKBDI):
        return _nfdrs4_bindings.NFDRS4_SetStartKBDI(self, sKBDI)

    def GetStartKBDI(self):
        return _nfdrs4_bindings.NFDRS4_GetStartKBDI(self)

    def SetSCMax(self, maxSC):
        return _nfdrs4_bindings.NFDRS4_SetSCMax(self, maxSC)

    def GetSCMax(self):
        return _nfdrs4_bindings.NFDRS4_GetSCMax(self)

    def SetMXD(self, mxd):
        return _nfdrs4_bindings.NFDRS4_SetMXD(self, mxd)

    def GetMXD(self):
        return _nfdrs4_bindings.NFDRS4_GetMXD(self)

    def GetFuelTemperature(self):
        return _nfdrs4_bindings.NFDRS4_GetFuelTemperature(self)

    def GetXDaysPrecipitation(self, nDays):
        return _nfdrs4_bindings.NFDRS4_GetXDaysPrecipitation(self, nDays)

    def ReadState(self, fileName):
        return _nfdrs4_bindings.NFDRS4_ReadState(self, fileName)

    def SaveState(self, fileName):
        return _nfdrs4_bindings.NFDRS4_SaveState(self, fileName)

    def LoadState(self, state):
        return _nfdrs4_bindings.NFDRS4_LoadState(self, state)
    nPrecipQueueDays = property(_nfdrs4_bindings.NFDRS4_nPrecipQueueDays_get)
    nHoursPerDay = property(_nfdrs4_bindings.NFDRS4_nHoursPerDay_get)

    def GetMinTemp(self):
        return _nfdrs4_bindings.NFDRS4_GetMinTemp(self)

    def GetMaxTemp(self):
        return _nfdrs4_bindings.NFDRS4_GetMaxTemp(self)

    def GetMinRH(self):
        return _nfdrs4_bindings.NFDRS4_GetMinRH(self)

    def GetPcp24(self):
        return _nfdrs4_bindings.NFDRS4_GetPcp24(self)

    def AddCustomFuel(self, fmParams):
        return _nfdrs4_bindings.NFDRS4_AddCustomFuel(self, fmParams)
    CTA = property(_nfdrs4_bindings.NFDRS4_CTA_get, _nfdrs4_bindings.NFDRS4_CTA_set)
    Lat = property(_nfdrs4_bindings.NFDRS4_Lat_get, _nfdrs4_bindings.NFDRS4_Lat_set)
    NFDRSVersion = property(_nfdrs4_bindings.NFDRS4_NFDRSVersion_get, _nfdrs4_bindings.NFDRS4_NFDRSVersion_set)
    YesterdayJDay = property(_nfdrs4_bindings.NFDRS4_YesterdayJDay_get, _nfdrs4_bindings.NFDRS4_YesterdayJDay_set)
    SlopeClass = property(_nfdrs4_bindings.NFDRS4_SlopeClass_get, _nfdrs4_bindings.NFDRS4_SlopeClass_set)
    OneHourFM = property(_nfdrs4_bindings.NFDRS4_OneHourFM_get, _nfdrs4_bindings.NFDRS4_OneHourFM_set)
    TenHourFM = property(_nfdrs4_bindings.NFDRS4_TenHourFM_get, _nfdrs4_bindings.NFDRS4_TenHourFM_set)
    HundredHourFM = property(_nfdrs4_bindings.NFDRS4_HundredHourFM_get, _nfdrs4_bindings.NFDRS4_HundredHourFM_set)
    ThousandHourFM = property(_nfdrs4_bindings.NFDRS4_ThousandHourFM_get, _nfdrs4_bindings.NFDRS4_ThousandHourFM_set)
    HerbFM = property(_nfdrs4_bindings.NFDRS4_HerbFM_get, _nfdrs4_bindings.NFDRS4_HerbFM_set)
    WoodyFM = property(_nfdrs4_bindings.NFDRS4_WoodyFM_get, _nfdrs4_bindings.NFDRS4_WoodyFM_set)
    FuelModel = property(_nfdrs4_bindings.NFDRS4_FuelModel_get, _nfdrs4_bindings.NFDRS4_FuelModel_set)
    FuelDescription = property(_nfdrs4_bindings.NFDRS4_FuelDescription_get, _nfdrs4_bindings.NFDRS4_FuelDescription_set)
    SG1 = property(_nfdrs4_bindings.NFDRS4_SG1_get, _nfdrs4_bindings.NFDRS4_SG1_set)
    SG10 = property(_nfdrs4_bindings.NFDRS4_SG10_get, _nfdrs4_bindings.NFDRS4_SG10_set)
    SG100 = property(_nfdrs4_bindings.NFDRS4_SG100_get, _nfdrs4_bindings.NFDRS4_SG100_set)
    SG1000 = property(_nfdrs4_bindings.NFDRS4_SG1000_get, _nfdrs4_bindings.NFDRS4_SG1000_set)
    SGWOOD = property(_nfdrs4_bindings.NFDRS4_SGWOOD_get, _nfdrs4_bindings.NFDRS4_SGWOOD_set)
    SGHERB = property(_nfdrs4_bindings.NFDRS4_SGHERB_get, _nfdrs4_bindings.NFDRS4_SGHERB_set)
    W1 = property(_nfdrs4_bindings.NFDRS4_W1_get, _nfdrs4_bindings.NFDRS4_W1_set)
    W10 = property(_nfdrs4_bindings.NFDRS4_W10_get, _nfdrs4_bindings.NFDRS4_W10_set)
    W100 = property(_nfdrs4_bindings.NFDRS4_W100_get, _nfdrs4_bindings.NFDRS4_W100_set)
    W1000 = property(_nfdrs4_bindings.NFDRS4_W1000_get, _nfdrs4_bindings.NFDRS4_W1000_set)
    WWOOD = property(_nfdrs4_bindings.NFDRS4_WWOOD_get, _nfdrs4_bindings.NFDRS4_WWOOD_set)
    WHERB = property(_nfdrs4_bindings.NFDRS4_WHERB_get, _nfdrs4_bindings.NFDRS4_WHERB_set)
    WDROUGHT = property(_nfdrs4_bindings.NFDRS4_WDROUGHT_get, _nfdrs4_bindings.NFDRS4_WDROUGHT_set)
    W1P = property(_nfdrs4_bindings.NFDRS4_W1P_get, _nfdrs4_bindings.NFDRS4_W1P_set)
    WHERBP = property(_nfdrs4_bindings.NFDRS4_WHERBP_get, _nfdrs4_bindings.NFDRS4_WHERBP_set)
    WTOT = property(_nfdrs4_bindings.NFDRS4_WTOT_get, _nfdrs4_bindings.NFDRS4_WTOT_set)
    L1 = property(_nfdrs4_bindings.NFDRS4_L1_get, _nfdrs4_bindings.NFDRS4_L1_set)
    L10 = property(_nfdrs4_bindings.NFDRS4_L10_get, _nfdrs4_bindings.NFDRS4_L10_set)
    L100 = property(_nfdrs4_bindings.NFDRS4_L100_get, _nfdrs4_bindings.NFDRS4_L100_set)
    L1000 = property(_nfdrs4_bindings.NFDRS4_L1000_get, _nfdrs4_bindings.NFDRS4_L1000_set)
    LWOOD = property(_nfdrs4_bindings.NFDRS4_LWOOD_get, _nfdrs4_bindings.NFDRS4_LWOOD_set)
    LHERB = property(_nfdrs4_bindings.NFDRS4_LHERB_get, _nfdrs4_bindings.NFDRS4_LHERB_set)
    LDROUGHT = property(_nfdrs4_bindings.NFDRS4_LDROUGHT_get, _nfdrs4_bindings.NFDRS4_LDROUGHT_set)
    DroughtUnit = property(_nfdrs4_bindings.NFDRS4_DroughtUnit_get, _nfdrs4_bindings.NFDRS4_DroughtUnit_set)
    fctCur = property(_nfdrs4_bindings.NFDRS4_fctCur_get, _nfdrs4_bindings.NFDRS4_fctCur_set)
    DEPTH = property(_nfdrs4_bindings.NFDRS4_DEPTH_get, _nfdrs4_bindings.NFDRS4_DEPTH_set)
    WNDFC = property(_nfdrs4_bindings.NFDRS4_WNDFC_get, _nfdrs4_bindings.NFDRS4_WNDFC_set)
    MXD = property(_nfdrs4_bindings.NFDRS4_MXD_get, _nfdrs4_bindings.NFDRS4_MXD_set)
    HD = property(_nfdrs4_bindings.NFDRS4_HD_get, _nfdrs4_bindings.NFDRS4_HD_set)
    SCM = property(_nfdrs4_bindings.NFDRS4_SCM_get, _nfdrs4_bindings.NFDRS4_SCM_set)
    MC1 = property(_nfdrs4_bindings.NFDRS4_MC1_get, _nfdrs4_bindings.NFDRS4_MC1_set)
    MC10 = property(_nfdrs4_bindings.NFDRS4_MC10_get, _nfdrs4_bindings.NFDRS4_MC10_set)
    MC100 = property(_nfdrs4_bindings.NFDRS4_MC100_get, _nfdrs4_bindings.NFDRS4_MC100_set)
    MC1000 = property(_nfdrs4_bindings.NFDRS4_MC1000_get, _nfdrs4_bindings.NFDRS4_MC1000_set)
    MCWOOD = property(_nfdrs4_bindings.NFDRS4_MCWOOD_get, _nfdrs4_bindings.NFDRS4_MCWOOD_set)
    MCHERB = property(_nfdrs4_bindings.NFDRS4_MCHERB_get, _nfdrs4_bindings.NFDRS4_MCHERB_set)
    BI = property(_nfdrs4_bindings.NFDRS4_BI_get, _nfdrs4_bindings.NFDRS4_BI_set)
    ERC = property(_nfdrs4_bindings.NFDRS4_ERC_get, _nfdrs4_bindings.NFDRS4_ERC_set)
    SC = property(_nfdrs4_bindings.NFDRS4_SC_get, _nfdrs4_bindings.NFDRS4_SC_set)
    IC = property(_nfdrs4_bindings.NFDRS4_IC_get, _nfdrs4_bindings.NFDRS4_IC_set)
    PrevYear = property(_nfdrs4_bindings.NFDRS4_PrevYear_get, _nfdrs4_bindings.NFDRS4_PrevYear_set)
    KBDI = property(_nfdrs4_bindings.NFDRS4_KBDI_get, _nfdrs4_bindings.NFDRS4_KBDI_set)
    YKBDI = property(_nfdrs4_bindings.NFDRS4_YKBDI_get, _nfdrs4_bindings.NFDRS4_YKBDI_set)
    StartKBDI = property(_nfdrs4_bindings.NFDRS4_StartKBDI_get, _nfdrs4_bindings.NFDRS4_StartKBDI_set)
    KBDIThreshold = property(_nfdrs4_bindings.NFDRS4_KBDIThreshold_get, _nfdrs4_bindings.NFDRS4_KBDIThreshold_set)
    CummPrecip = property(_nfdrs4_bindings.NFDRS4_CummPrecip_get, _nfdrs4_bindings.NFDRS4_CummPrecip_set)
    AvgPrecip = property(_nfdrs4_bindings.NFDRS4_AvgPrecip_get, _nfdrs4_bindings.NFDRS4_AvgPrecip_set)
    UseLoadTransfer = property(_nfdrs4_bindings.NFDRS4_UseLoadTransfer_get, _nfdrs4_bindings.NFDRS4_UseLoadTransfer_set)
    UseCuring = property(_nfdrs4_bindings.NFDRS4_UseCuring_get, _nfdrs4_bindings.NFDRS4_UseCuring_set)
    SnowCovered = property(_nfdrs4_bindings.NFDRS4_SnowCovered_get, _nfdrs4_bindings.NFDRS4_SnowCovered_set)
    WTMCD = property(_nfdrs4_bindings.NFDRS4_WTMCD_get, _nfdrs4_bindings.NFDRS4_WTMCD_set)
    WTMCL = property(_nfdrs4_bindings.NFDRS4_WTMCL_get, _nfdrs4_bindings.NFDRS4_WTMCL_set)
    WTMCDE = property(_nfdrs4_bindings.NFDRS4_WTMCDE_get, _nfdrs4_bindings.NFDRS4_WTMCDE_set)
    WTMCLE = property(_nfdrs4_bindings.NFDRS4_WTMCLE_get, _nfdrs4_bindings.NFDRS4_WTMCLE_set)
    FuelTemperature = property(_nfdrs4_bindings.NFDRS4_FuelTemperature_get, _nfdrs4_bindings.NFDRS4_FuelTemperature_set)
    m_GSI = property(_nfdrs4_bindings.NFDRS4_m_GSI_get, _nfdrs4_bindings.NFDRS4_m_GSI_set)
    nConsectiveSnowDays = property(_nfdrs4_bindings.NFDRS4_nConsectiveSnowDays_get, _nfdrs4_bindings.NFDRS4_nConsectiveSnowDays_set)
    m_regObsHour = property(_nfdrs4_bindings.NFDRS4_m_regObsHour_get, _nfdrs4_bindings.NFDRS4_m_regObsHour_set)
    utcHourDiff = property(_nfdrs4_bindings.NFDRS4_utcHourDiff_get, _nfdrs4_bindings.NFDRS4_utcHourDiff_set)
    lastUtcUpdateTime = property(_nfdrs4_bindings.NFDRS4_lastUtcUpdateTime_get, _nfdrs4_bindings.NFDRS4_lastUtcUpdateTime_set)
    lastDailyUpdateTime = property(_nfdrs4_bindings.NFDRS4_lastDailyUpdateTime_get, _nfdrs4_bindings.NFDRS4_lastDailyUpdateTime_set)
    qPrecip = property(_nfdrs4_bindings.NFDRS4_qPrecip_get, _nfdrs4_bindings.NFDRS4_qPrecip_set)
    qHourlyPrecip = property(_nfdrs4_bindings.NFDRS4_qHourlyPrecip_get, _nfdrs4_bindings.NFDRS4_qHourlyPrecip_set)
    qHourlyTemp = property(_nfdrs4_bindings.NFDRS4_qHourlyTemp_get, _nfdrs4_bindings.NFDRS4_qHourlyTemp_set)
    qHourlyRH = property(_nfdrs4_bindings.NFDRS4_qHourlyRH_get, _nfdrs4_bindings.NFDRS4_qHourlyRH_set)
    mapFuels = property(_nfdrs4_bindings.NFDRS4_mapFuels_get, _nfdrs4_bindings.NFDRS4_mapFuels_set)

# Register NFDRS4 in _nfdrs4_bindings:
_nfdrs4_bindings.NFDRS4_swigregister(NFDRS4)
class CGSIParams(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.CGSIParams_swiginit(self, _nfdrs4_bindings.new_CGSIParams(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_CGSIParams

    def getGsiMax(self):
        return _nfdrs4_bindings.CGSIParams_getGsiMax(self)

    def getGsiHerbGreenup(self):
        return _nfdrs4_bindings.CGSIParams_getGsiHerbGreenup(self)

    def getGsiTminMin(self):
        return _nfdrs4_bindings.CGSIParams_getGsiTminMin(self)

    def getGsiTminMax(self):
        return _nfdrs4_bindings.CGSIParams_getGsiTminMax(self)

    def getGsiVpdMin(self):
        return _nfdrs4_bindings.CGSIParams_getGsiVpdMin(self)

    def getGsiVpdMax(self):
        return _nfdrs4_bindings.CGSIParams_getGsiVpdMax(self)

    def getGsiDaylenMin(self):
        return _nfdrs4_bindings.CGSIParams_getGsiDaylenMin(self)

    def getGsiDaylenMax(self):
        return _nfdrs4_bindings.CGSIParams_getGsiDaylenMax(self)

    def getGsiAveragingPeriod(self):
        return _nfdrs4_bindings.CGSIParams_getGsiAveragingPeriod(self)

    def getUseVpdAverage(self):
        return _nfdrs4_bindings.CGSIParams_getUseVpdAverage(self)

    def getNumPrecipDays(self):
        return _nfdrs4_bindings.CGSIParams_getNumPrecipDays(self)

    def getRunningTotalPrecipMin(self):
        return _nfdrs4_bindings.CGSIParams_getRunningTotalPrecipMin(self)

    def getRunningTotalPrecipMax(self):
        return _nfdrs4_bindings.CGSIParams_getRunningTotalPrecipMax(self)

    def getLiveFuelMoistureMin(self):
        return _nfdrs4_bindings.CGSIParams_getLiveFuelMoistureMin(self)

    def getLiveFuelMoistureMax(self):
        return _nfdrs4_bindings.CGSIParams_getLiveFuelMoistureMax(self)

    def getUseRTPrecip(self):
        return _nfdrs4_bindings.CGSIParams_getUseRTPrecip(self)

    def setGsiMax(self, gsiMax):
        return _nfdrs4_bindings.CGSIParams_setGsiMax(self, gsiMax)

    def setGsiHerbGreenup(self, gsiHerbGreenup):
        return _nfdrs4_bindings.CGSIParams_setGsiHerbGreenup(self, gsiHerbGreenup)

    def setGsiTminMin(self, gsiTMinMin):
        return _nfdrs4_bindings.CGSIParams_setGsiTminMin(self, gsiTMinMin)

    def setGsiTminMax(self, gsiTMinMax):
        return _nfdrs4_bindings.CGSIParams_setGsiTminMax(self, gsiTMinMax)

    def setGsiVpdMin(self, gsiVpdMin):
        return _nfdrs4_bindings.CGSIParams_setGsiVpdMin(self, gsiVpdMin)

    def setGsiVpdMax(self, gsiVpdMax):
        return _nfdrs4_bindings.CGSIParams_setGsiVpdMax(self, gsiVpdMax)

    def setGsiDaylenMin(self, gsiDaylenMin):
        return _nfdrs4_bindings.CGSIParams_setGsiDaylenMin(self, gsiDaylenMin)

    def setGsiDaylenMax(self, gsiDaylenMax):
        return _nfdrs4_bindings.CGSIParams_setGsiDaylenMax(self, gsiDaylenMax)

    def setGsiAveragingPeriod(self, gsiAveragingPeriod):
        return _nfdrs4_bindings.CGSIParams_setGsiAveragingPeriod(self, gsiAveragingPeriod)

    def setUseVpdAverage(self, useVPDAverage):
        return _nfdrs4_bindings.CGSIParams_setUseVpdAverage(self, useVPDAverage)

    def setNumPrecipDays(self, numPrecipDays):
        return _nfdrs4_bindings.CGSIParams_setNumPrecipDays(self, numPrecipDays)

    def setRunningTotalPrecipMin(self, rtPrecipMin):
        return _nfdrs4_bindings.CGSIParams_setRunningTotalPrecipMin(self, rtPrecipMin)

    def setRunningTotalPrecipMax(self, rtPrecipMax):
        return _nfdrs4_bindings.CGSIParams_setRunningTotalPrecipMax(self, rtPrecipMax)

    def setLiveFuelMoistureMin(self, liveFuelMoistureMin):
        return _nfdrs4_bindings.CGSIParams_setLiveFuelMoistureMin(self, liveFuelMoistureMin)

    def setLiveFuelMoistureMax(self, liveFuelMoistureMax):
        return _nfdrs4_bindings.CGSIParams_setLiveFuelMoistureMax(self, liveFuelMoistureMax)

    def setUseRTPrecip(self, useRTPrecip):
        return _nfdrs4_bindings.CGSIParams_setUseRTPrecip(self, useRTPrecip)

# Register CGSIParams in _nfdrs4_bindings:
_nfdrs4_bindings.CGSIParams_swigregister(CGSIParams)
class CDeadFuelMoistureParams(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.CDeadFuelMoistureParams_swiginit(self, _nfdrs4_bindings.new_CDeadFuelMoistureParams(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_CDeadFuelMoistureParams

    def getRadius(self):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_getRadius(self)

    def getAdsorptionRate(self):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_getAdsorptionRate(self)

    def getStickDensity(self):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_getStickDensity(self)

    def getMaxLocalMoisture(self):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_getMaxLocalMoisture(self)

    def getDesorptionRate(self):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_getDesorptionRate(self)

    def setRadius(self, radius):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_setRadius(self, radius)

    def setAdsorptionRate(self, adsortionRate):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_setAdsorptionRate(self, adsortionRate)

    def setStickDensity(self, stickDensity):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_setStickDensity(self, stickDensity)

    def setMaxLocalMoisture(self, maxLocalMoisture):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_setMaxLocalMoisture(self, maxLocalMoisture)

    def setDesortionRate(self, desorptionRate):
        return _nfdrs4_bindings.CDeadFuelMoistureParams_setDesortionRate(self, desorptionRate)

# Register CDeadFuelMoistureParams in _nfdrs4_bindings:
_nfdrs4_bindings.CDeadFuelMoistureParams_swigregister(CDeadFuelMoistureParams)
class CNFDRSParams(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.CNFDRSParams_swiginit(self, _nfdrs4_bindings.new_CNFDRSParams(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_CNFDRSParams

    def InitNFDRS(self, pNFDRS):
        return _nfdrs4_bindings.CNFDRSParams_InitNFDRS(self, pNFDRS)

    def getFuelModel(self):
        return _nfdrs4_bindings.CNFDRSParams_getFuelModel(self)

    def getMaxSC(self):
        return _nfdrs4_bindings.CNFDRSParams_getMaxSC(self)

    def getLatitude(self):
        return _nfdrs4_bindings.CNFDRSParams_getLatitude(self)

    def getSlopeClass(self):
        return _nfdrs4_bindings.CNFDRSParams_getSlopeClass(self)

    def getAvgAnnualPrecip(self):
        return _nfdrs4_bindings.CNFDRSParams_getAvgAnnualPrecip(self)

    def getUseLoadTransfer(self):
        return _nfdrs4_bindings.CNFDRSParams_getUseLoadTransfer(self)

    def getUseCure(self):
        return _nfdrs4_bindings.CNFDRSParams_getUseCure(self)

    def getIsAnnual(self):
        return _nfdrs4_bindings.CNFDRSParams_getIsAnnual(self)

    def getKbdiThreshold(self):
        return _nfdrs4_bindings.CNFDRSParams_getKbdiThreshold(self)

    def getStartKbdi(self):
        return _nfdrs4_bindings.CNFDRSParams_getStartKbdi(self)

    def getMXD(self):
        return _nfdrs4_bindings.CNFDRSParams_getMXD(self)

    def getObsHour(self):
        return _nfdrs4_bindings.CNFDRSParams_getObsHour(self)

    def getTimeZoneOffsetHours(self):
        return _nfdrs4_bindings.CNFDRSParams_getTimeZoneOffsetHours(self)

    def getGsiParams(self):
        return _nfdrs4_bindings.CNFDRSParams_getGsiParams(self)

    def getHerbParams(self):
        return _nfdrs4_bindings.CNFDRSParams_getHerbParams(self)

    def getWoodyParams(self):
        return _nfdrs4_bindings.CNFDRSParams_getWoodyParams(self)

    def get1HourParams(self):
        return _nfdrs4_bindings.CNFDRSParams_get1HourParams(self)

    def get10HourParams(self):
        return _nfdrs4_bindings.CNFDRSParams_get10HourParams(self)

    def get100HourParams(self):
        return _nfdrs4_bindings.CNFDRSParams_get100HourParams(self)

    def get1000HourParams(self):
        return _nfdrs4_bindings.CNFDRSParams_get1000HourParams(self)

    def getFuelModelParams(self):
        return _nfdrs4_bindings.CNFDRSParams_getFuelModelParams(self)

    def setFuelModel(self, fuelModel):
        return _nfdrs4_bindings.CNFDRSParams_setFuelModel(self, fuelModel)

    def setMaxSC(self, maxSC):
        return _nfdrs4_bindings.CNFDRSParams_setMaxSC(self, maxSC)

    def setLatitude(self, latitude):
        return _nfdrs4_bindings.CNFDRSParams_setLatitude(self, latitude)

    def setSlopeClass(self, slopeClass):
        return _nfdrs4_bindings.CNFDRSParams_setSlopeClass(self, slopeClass)

    def setAvgAnnualPrecip(self, avgAnnualPrecip):
        return _nfdrs4_bindings.CNFDRSParams_setAvgAnnualPrecip(self, avgAnnualPrecip)

    def setUseLoadTransfer(self, useLoadTransfer):
        return _nfdrs4_bindings.CNFDRSParams_setUseLoadTransfer(self, useLoadTransfer)

    def setUseCure(self, useCure):
        return _nfdrs4_bindings.CNFDRSParams_setUseCure(self, useCure)

    def setIsAnnual(self, isAnnual):
        return _nfdrs4_bindings.CNFDRSParams_setIsAnnual(self, isAnnual)

    def setKbdiThreshold(self, kbdiThreshold):
        return _nfdrs4_bindings.CNFDRSParams_setKbdiThreshold(self, kbdiThreshold)

    def setStartKbdi(self, startKbdi):
        return _nfdrs4_bindings.CNFDRSParams_setStartKbdi(self, startKbdi)

    def setMXD(self, mxd):
        return _nfdrs4_bindings.CNFDRSParams_setMXD(self, mxd)

    def setObsHour(self, obsHour):
        return _nfdrs4_bindings.CNFDRSParams_setObsHour(self, obsHour)

    def setTimeZoneOffsetHours(self, offset):
        return _nfdrs4_bindings.CNFDRSParams_setTimeZoneOffsetHours(self, offset)

    def setGsiParams(self, gsiParams):
        return _nfdrs4_bindings.CNFDRSParams_setGsiParams(self, gsiParams)

    def setHerbParams(self, herbParams):
        return _nfdrs4_bindings.CNFDRSParams_setHerbParams(self, herbParams)

    def setWoodyParams(self, woodyParams):
        return _nfdrs4_bindings.CNFDRSParams_setWoodyParams(self, woodyParams)

    def set1HourParams(self, oneHourParams):
        return _nfdrs4_bindings.CNFDRSParams_set1HourParams(self, oneHourParams)

    def set10HourParams(self, tenHourParams):
        return _nfdrs4_bindings.CNFDRSParams_set10HourParams(self, tenHourParams)

    def set100HourParams(self, hundredHourParams):
        return _nfdrs4_bindings.CNFDRSParams_set100HourParams(self, hundredHourParams)

    def set1000HourParams(self, thousandHourParams):
        return _nfdrs4_bindings.CNFDRSParams_set1000HourParams(self, thousandHourParams)

    def setFuelModelParams(self, fuelModelParams):
        return _nfdrs4_bindings.CNFDRSParams_setFuelModelParams(self, fuelModelParams)

# Register CNFDRSParams in _nfdrs4_bindings:
_nfdrs4_bindings.CNFDRSParams_swigregister(CNFDRSParams)
class UTCTimeException(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.UTCTimeException_swiginit(self, _nfdrs4_bindings.new_UTCTimeException(*args))
    __swig_destroy__ = _nfdrs4_bindings.delete_UTCTimeException

    def what(self):
        return _nfdrs4_bindings.UTCTimeException_what(self)

# Register UTCTimeException in _nfdrs4_bindings:
_nfdrs4_bindings.UTCTimeException_swigregister(UTCTimeException)
class bad_time_init(UTCTimeException):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _nfdrs4_bindings.bad_time_init_swiginit(self, _nfdrs4_bindings.new_bad_time_init())
    __swig_destroy__ = _nfdrs4_bindings.delete_bad_time_init

# Register bad_time_init in _nfdrs4_bindings:
_nfdrs4_bindings.bad_time_init_swigregister(bad_time_init)
class bad_time(UTCTimeException):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _nfdrs4_bindings.bad_time_swiginit(self, _nfdrs4_bindings.new_bad_time())
    __swig_destroy__ = _nfdrs4_bindings.delete_bad_time

# Register bad_time in _nfdrs4_bindings:
_nfdrs4_bindings.bad_time_swigregister(bad_time)
class invalid_date(UTCTimeException):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, msg):
        _nfdrs4_bindings.invalid_date_swiginit(self, _nfdrs4_bindings.new_invalid_date(msg))
    __swig_destroy__ = _nfdrs4_bindings.delete_invalid_date

# Register invalid_date in _nfdrs4_bindings:
_nfdrs4_bindings.invalid_date_swigregister(invalid_date)

def validate_date(year, month, day, hour, minute, second):
    return _nfdrs4_bindings.validate_date(year, month, day, hour, minute, second)

def get_day_diff():
    return _nfdrs4_bindings.get_day_diff()

def get_hour_diff():
    return _nfdrs4_bindings.get_hour_diff()

def get_sec_diff():
    return _nfdrs4_bindings.get_sec_diff()

def tm_compare(first, second):
    return _nfdrs4_bindings.tm_compare(first, second)

def tm_intraday_secs_diff(first, second):
    return _nfdrs4_bindings.tm_intraday_secs_diff(first, second)

def is_leap_year(year):
    return _nfdrs4_bindings.is_leap_year(year)

def tm_increment_day(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_increment_day(changing_tm, quantity)

def tm_increment_hour(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_increment_hour(changing_tm, quantity)

def tm_increment_minute(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_increment_minute(changing_tm, quantity)

def tm_increment_second(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_increment_second(changing_tm, quantity)

def tm_decrement_day(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_decrement_day(changing_tm, quantity)

def tm_decrement_hour(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_decrement_hour(changing_tm, quantity)

def tm_decrement_minute(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_decrement_minute(changing_tm, quantity)

def tm_decrement_second(changing_tm, quantity=1):
    return _nfdrs4_bindings.tm_decrement_second(changing_tm, quantity)

def check_utc_timestamp(check_time, secs_diff, year, month, day, hour, minute, second):
    return _nfdrs4_bindings.check_utc_timestamp(check_time, secs_diff, year, month, day, hour, minute, second)

def get_utc_timestamp(year, month, day, hour, minute, second):
    return _nfdrs4_bindings.get_utc_timestamp(year, month, day, hour, minute, second)

def get_utc_timestamp_sec_diff(check_time, year, month, day, hour, minute, second):
    return _nfdrs4_bindings.get_utc_timestamp_sec_diff(check_time, year, month, day, hour, minute, second)
class UTCTime(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _nfdrs4_bindings.UTCTime_swiginit(self, _nfdrs4_bindings.new_UTCTime(*args))

    def get_tm(self):
        return _nfdrs4_bindings.UTCTime_get_tm(self)

    def time_string(self):
        return _nfdrs4_bindings.UTCTime_time_string(self)

    def time_string_inet(self):
        return _nfdrs4_bindings.UTCTime_time_string_inet(self)

    def timestamp(self):
        return _nfdrs4_bindings.UTCTime_timestamp(self)

    def __lt__(self, rhs):
        return _nfdrs4_bindings.UTCTime___lt__(self, rhs)

    def __ge__(self, rhs):
        return _nfdrs4_bindings.UTCTime___ge__(self, rhs)

    def __gt__(self, rhs):
        return _nfdrs4_bindings.UTCTime___gt__(self, rhs)

    def __le__(self, rhs):
        return _nfdrs4_bindings.UTCTime___le__(self, rhs)

    def __eq__(self, rhs):
        return _nfdrs4_bindings.UTCTime___eq__(self, rhs)

    def __ne__(self, rhs):
        return _nfdrs4_bindings.UTCTime___ne__(self, rhs)

    def __sub__(self, rhs):
        return _nfdrs4_bindings.UTCTime___sub__(self, rhs)
    __swig_destroy__ = _nfdrs4_bindings.delete_UTCTime

# Register UTCTime in _nfdrs4_bindings:
_nfdrs4_bindings.UTCTime_swigregister(UTCTime)

